#!/usr/bin/python

import pyglet

from prime.system.window import Window
from prime.graphics.prims import GRectangle

from components import Board
from components import MainPanel

# Default game constants.
ROWS = 8
PEGS = 4
COLORS = 4 # Must be larger or equal to PEGS.
COLOR_REPEAT = False

PADDING = 20 # Window padding.

pyglet.resource.path = ['img']
pyglet.resource.reindex()

icon128 = pyglet.image.load("img/icon_128x128.png")
icon64 = pyglet.image.load("img/icon_64x64.png")
icon32 = pyglet.image.load("img/icon_32x32.png")
icon16 = pyglet.image.load("img/icon_16x16.png")

window = Window(caption="Mastermind", visible=False)
window.set_icon(icon128, icon64, icon32, icon16)

# Game board.
board = Board(20, 20, rows=ROWS, pegs=PEGS, colors=COLORS,
        color_repeat=COLOR_REPEAT)
main_panel = MainPanel(x=20, y=0, board=board)

window.set_size(main_panel.width + 2 * PADDING,
        main_panel.height + 2 * PADDING - 20)

# Background color.
back = GRectangle(0, 0, window.width, window.height, color=(66, 66, 66))

window.add(back)
window.add(main_panel)

window.set_visible()

pyglet.app.run()
