import pyglet

from pyglet.gl import GL_QUADS
from pyglet.gl import GL_LINES
from pyglet.gl import GL_POINTS

from prime.graphics.base import Graphic

class GRectangle(Graphic):
    """Rectangle in pyglet."""

    def __init__(self, x=0, y=0, width=20, height=20, color=(255, 255, 255)):
        super(GRectangle, self).__init__(x, y, width, height)
        self.color = color

    def draw(self):
        pyglet.graphics.draw(4, GL_QUADS,
                ("c3B", 4 * self.color),
                ("v2f", (
                    self.x, self.y + self.height,
                    self.x + self.width, self.y + self.height,
                    self.x + self.width, self.y,
                    self.x, self.y)))

class GLine(Graphic):
    """Line in pyglet."""

    def __init__(self, x1=0, y1=0, x2=0, y2=0, color=(255, 255, 255)):
        self.x1 = x1
        self.x2 = x2
        self.y1 = y1
        self.y2 = y2
        self.color = color

    @property
    def width(self):
        return abs(self.x1 - self.x2) or 1

    @property
    def height(self):
        return abs(self.y1 - self.y2) or 1

    @property
    def x(self):
        return min(self.x1, self.x2)

    @x.setter
    def x(self, value):
        diff = self.x - value
        self.x1 -= diff
        self.x2 -= diff

    @property
    def y(self):
        return min(self.y1, self.y2)

    @y.setter
    def y(self, value):
        diff = self.y - value
        self.y1 -= diff
        self.y2 -= diff

    def draw(self):
        pyglet.graphics.draw(2, GL_LINES,
                ("c3B", 2 * self.color),
                ("v2f", (self.x1, self.y1,
                    self.x2, self.y2)))

class GPoint(Graphic):
    """Point in pyglet."""

    def __init__(self, x=0, y=0, color=(255, 255, 255)):
        self.x = x
        self.y = y
        self.color = color

    @property
    def width(self):
        return 1

    @property
    def height(self):
        return 1

    def draw(self):
        pyglet.graphics.draw(1, GL_POINTS,
                ("c3B", self.color),
                ("v2f", (self.x, self.y)))
