import pyglet

from prime.graphics.base import Graphic

class Image(Graphic):

    def __init__(self, x=0, y=0, image=None):
        """image -- pyglet resource path."""

        img = pyglet.resource.image(image)
        self.sprite = pyglet.sprite.Sprite(img, x, y)

    @property
    def width(self): return self.sprite.width

    @property
    def height(self): return self.sprite.height

    @property
    def x(self): return self.sprite.x

    @x.setter
    def x(self, value): self.sprite.x = value

    @property
    def y(self): return self.sprite.y

    @y.setter
    def y(self, value): self.sprite.y = value

    def draw(self): self.sprite.draw()

class SeqImage(Image):
    """Graphic which contains multiple images."""

    def __init__(self, x=0, y=0, rows=1, cols=1, image=None):
        """image -- pyglet resource path."""
        
        self._img_index = 0
        self.rows = rows
        self.cols = cols

        img = pyglet.resource.image(image)
        img_seq = pyglet.image.ImageGrid(img, rows, cols)

        self.img_seq = pyglet.image.TextureGrid(img_seq)
        self.sprite = pyglet.sprite.Sprite(self.img_seq[self.img_index], x, y)

    @property
    def img_index(self): return self._img_index

    @img_index.setter
    def img_index(self, value):
        self._img_index = value
        self.sprite.image = self.img_seq[self._img_index]
