from prime.widgets.panels import Panel

class PanelEventHandler(object):

    def __init__(self):
        self.last_press = None # Last pressed widget without release.
        self.in_widget = None # Current inside widget.  Mouse motion.
        self.hit_something = False # If hit something in panel.

    def event_mouse_press(self, panel, x, y, buttons, modifiers):
        for widget in reversed(panel.widgets):

            if widget.hits(x, y):
                if isinstance(widget, Panel):
                    self.event_mouse_press(widget, x, y, buttons, modifiers)
                    continue

                self.hit_something = True
                widget.mouse_press()

                # Begin tracking, possible click on release.
                self.last_press = widget
                break

    def event_mouse_release(self, panel, x, y, buttons, modifiers):
        for widget in reversed(panel.widgets):

            if widget.hits(x, y):
                if isinstance(widget, Panel):
                    self.event_mouse_release(widget, x, y, buttons, modifiers)
                    continue

                self.hit_something = True
                widget.mouse_release()
                
                # Last press was on this widget -- a click event.
                if self.last_press == widget:
                    widget.click()
                    self.last_press = None

                # After a click event, widget might change.
                if widget.hits(x, y):
                    widget.hover()
                else:
                    widget.nohover()

                break

    def event_mouse_motion(self, panel, x, y, dx, dy, drag=False):
        for widget in reversed(panel.widgets):

            if widget.hits(x, y):
                if isinstance(widget, Panel):
                    self.event_mouse_motion(widget, x, y, dx, dy, drag=drag)
                    continue

                self.inside = True
                widget.mouse_motion()

                # Mouse enters the other widget.
                if widget != self.in_widget:

                    # Mouse leaves current in_widget
                    if not self.in_widget is None:
                        self.in_widget.mouse_leave()
                        self.in_widget.nohover()

                    # Widget was pressed.
                    if self.last_press == widget:
                        widget.mouse_press()

                    widget.mouse_enter()

                    if not drag:
                        widget.hover()

                self.in_widget = widget
                break

    def event_mouse_drag(self, panel, x, y, dx, dy, buttons, modifiers):
        self.event_mouse_motion(panel, x, y, dx, dy, drag=True)
